@@ -178,8 +178,15 @@ def import_dispatch(self, importqueue_pk, insert_size=5, slice_size=1000):
         pg_import_file(load.pk)
         return True
     except:
-        logger.info("Encountered an error while importing %s. Check logs for details." % load)
-        load.fail(sys.exc_info()[0])
+        message = "Encountered an error while importing %s. Check logs for details." % load
+        logger.info(message)
+        try:
+            message = str(sys.exc_info())
+        except:
+            pass
+        finally:
+            load.fail(message)
+            
         return False
     
     # FROM HERE BELOW, SPLIT OFF PSYCOPG2 VS NOT
@@ -512,9 +519,15 @@ def stage_dispatch(self, stagingqueue_pk):
         pg_stage(stg_q.pk)
         return True
     except:
-        logger.info("Encountered an error while staging %s. Check logs for details." % stg_q)
-        stg_q.fail(sys.exc_info()[0])
-        return False
+        message = "Encountered an error while staging %s. Check logs for details." % stg_q
+        logger.info(message)
+        try:
+            message = str(sys.exc_info())
+        except:
+            pass
+        finally:
+            stg_q.fail(message)
+            return False
 
 
 @celery.shared_task(bind=True, ignore_result=True)
