@@ -16,22 +16,22 @@ ds_patterns = patterns('',
 file_patterns = patterns('',
     url(r'(?P<obj_id>\d+)/$', obj_detail, {'obj_type': 'File'}, name='file_detail'),
     url(r'(?P<year>\d+|all)/(?P<state_abbr>[A-Z]{2}|all)/$', obj_inventory, {'obj_type': 'File'}, name='file_inv'),
-    url(r'discover/$', file_discover),
-    url(r'match/$', file_match),
+    url(r'discover/$', file_discover, name='file_discover'),
+    url(r'match/$', file_match, name='file_match'),
     url(r'$', obj_inventory, {'obj_type': 'File'}, name='file_inv'),
 )
 
 ibatch_patterns = patterns('',
     url(r'(?P<obj_id>\d+)/$', obj_detail, {'obj_type': 'ImportBatch'}, name='imb_detail'),
     url(r'(?P<obj_id>\d+)/run/$', run_batch, {'obj_type': 'ImportBatch'}, name='imb_run'),
-    url(r'unimported_batch/$', create_batch_from_unimported),
+    url(r'unimported_batch/$', create_batch_from_unimported, name='imb_unimported'),
     url(r'$', obj_inventory, {'obj_type': 'ImportBatch'}, name='imb_inv'),
 )
 
 stbatch_patterns = patterns('',
     url(r'(?P<obj_id>\d+)/$', obj_detail, {'obj_type': 'StagingBatch'}, name='stb_detail'),
     url(r'(?P<obj_id>\d+)/run/$', run_batch, {'obj_type': 'StagingBatch'}, name='stb_run'),
-    url(r'unprocessed_batch/$', batch_from_unprocessed),
+    url(r'unprocessed_batch/$', batch_from_unprocessed, name='stb_ununprocessed'),
     url(r'$', obj_inventory, {'obj_type': 'StagingBatch'}, name='stb_inv'),
 )
 
