@@ -24,6 +24,10 @@ from django.db.models import Q
 from django.contrib.auth.decorators import login_required
 
 
+# sister app imports
+from djhcup_core.utils import installed_modules
+
+
 # local project and app packages
 import djhcup_staging
 from djhcup_staging import tasks
@@ -68,6 +72,7 @@ def index(request):
     context = {
         'title': 'Hachoir: Staging', 
         'links': link_list,
+        'djhcup_components': installed_modules()
         }
     template = 'stg_base.html' #automagically looks in the templates directory for this app
     return render(request, template, context)
@@ -160,6 +165,7 @@ def obj_detail(request, obj_id, obj_type, msg_pt=[]):
         template = 'stg_detail_col.html'
     
     context['messages'] = msg_pt
+    context['djhcup_components'] = installed_modules()
     
     return render(request, template, context)
 
@@ -295,6 +301,7 @@ def obj_inventory(request, obj_type, msg_pt=[], *args, **kwargs):
         template = 'stg_inv_tbl.html'
     
     context['messages'] = msg_pt
+    context['djhcup_components'] = installed_modules()
     
     return render(request, template, context)
 
@@ -335,7 +342,7 @@ def create_batch_from_unimported(request):
     message = 'Created ImportBatch {pk} with {length} files' \
         .format(pk=b.pk, length=len(b.importqueue_set.all()))
     
-    return obj_detail(request, obj_id=b.pk, obj_type="StagingBatch", msg_pt=[message])
+    return obj_detail(request, obj_id=b.pk, obj_type="ImportBatch", msg_pt=[message])
     #return importbatch_inventory(request, msg_pass_through=[message])
 
 
@@ -366,6 +373,7 @@ def batch_reset_dead(request):
         'title': 'Import Batch',
         'response_messages': [{'content': response, 'type': 'info'}],
         }
+    context['djhcup_components'] = installed_modules()
     template = 'stg_base.html'
     return render(request, template, context)
 
@@ -407,6 +415,7 @@ def source_populate_defaults(request):
         'response_messages': response_messages,
         }
     
+    context['djhcup_components'] = installed_modules()
     template = 'stg_base.html'
     return render(request, template, context)
 
@@ -543,9 +552,7 @@ def file_match(request):
             matches_made += 1
     
     message = "Matched %s pairs of files with unambiguous similarity." % matches_made
-    logger.info(message)
-    
+    logger.info(message)    
     messages.append(dict(level="info", content=message))
     
     return obj_inventory(request, 'File', msg_pass_through=messages)
-
